#
# spec file for package xf86-input-wacom
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xf86-input-wacom
Version:        0.34.2
Release:        6.1
Summary:        Wacom input driver for the Xorg X server
License:        GPL-2.0-or-later
Group:          System/X11/Servers/XF86_4
Url:            http://sourceforge.net/apps/mediawiki/linuxwacom/index.php?title=Xf86-input-wacom
Source0:        http://downloads.sourceforge.net/project/linuxwacom/xf86-input-wacom/%{name}-%{version}.tar.bz2
Patch7:         n_01-Add-option-to-enable-logging.patch
Patch8:         n_02-Log-PROXIMITY-LOW-LEVEL-events.patch
Patch9:         n_03-Log-PRESSURE-low-level-events.patch
Patch10:        n_04-Log-BUTTON-HIGH-LEVEL-events.patch
# For directory ownership
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(inputproto)
BuildRequires:  pkgconfig(kbproto)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(randrproto)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xorg-server) >= 1.7.0
BuildRequires:  pkgconfig(xproto)
BuildRequires:  pkgconfig(xrandr)
Requires:       pkgconfig(udev)
Supplements:    xorg-x11-server
# This was part of the xorg-x11-driver-input package up to version 7.6
Conflicts:      xorg-x11-driver-input <= 7.6
Provides:       x11-input-wacom = %{version}
Obsoletes:      x11-input-wacom < %{version}
Provides:       x11-input-wacom-tools = %{version}
Obsoletes:      x11-input-wacom-tools < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExcludeArch:    s390 s390x
%{?systemd_ordering}
%{x11_abi_xinput_req}

%description
wacom is an X input driver and utilities for Wacom devices.

%package devel
Summary:        Development files for the Xorg X server Wacom input driver
Group:          Development/Libraries/X11
Requires:       %{name} = %{version}
Provides:       x11-input-wacom-devel = %{version}
Obsoletes:      x11-input-wacom-devel < %{version}

%description devel
wacom is an X input driver and utilities for Wacom devices.

%prep
%setup -q
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1

%build
autoreconf -fi
%configure \
    --with-xorg-conf-dir=%{_sysconfdir}/X11/xorg.conf.d \
    --enable-logging \
    --with-systemd-unit-dir=%{_unitdir} \
    --with-udev-rules-dir=%{_udevrulesdir} \
    --disable-silent-rules
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
mv %{buildroot}%{_udevrulesdir}/wacom.rules  %{buildroot}%{_udevrulesdir}/65-wacom.rules

%check
make %{?_smp_mflags} check

%pre
%service_add_pre wacom-inputattach@.service

%post
%service_add_post wacom-inputattach@.service
if [ "$1" -eq 1 ]; then
    %udev_rules_update
    %{_bindir}/systemctl daemon-reload >/dev/null 2>&1 || :
fi
# re-plug the input devices
udevadm trigger --subsystem-match=input --action=change
exit 0

%preun
%service_del_preun wacom-inputattach@.service

%postun
%service_del_postun wacom-inputattach@.service
if [ "$1" -eq 1 ]; then
    %udev_rules_update
    %{_bindir}/systemctl daemon-reload >/dev/null 2>&1 || :
fi
# re-plug the input devices
udevadm trigger --subsystem-match=input --action=change
exit 0

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog GPL README
%{_udevrulesdir}/65-wacom.rules
%{_unitdir}/wacom-inputattach@.service
%config %{_sysconfdir}/X11/xorg.conf.d/70-wacom.conf
%dir %{_libdir}/xorg/modules/input
%{_libdir}/xorg/modules/input/wacom_drv.so
%{_bindir}/xsetwacom
%{_mandir}/man1/xsetwacom.1%{?ext_man}
%{_mandir}/man4/wacom.4%{?ext_man}
%{_bindir}/isdv4-serial-inputattach

%files devel
%defattr(-,root,root)
%{_includedir}/xorg/Xwacom.h
%{_includedir}/xorg/isdv4.h
%{_includedir}/xorg/wacom-properties.h
%{_includedir}/xorg/wacom-util.h
# not useful for most people
%{_bindir}/isdv4-serial-debugger
%{_libdir}/pkgconfig/xorg-wacom.pc

%changelog
* Thu Mar 21 2019 Jan Engelhardt <jengelh@inai.de>
- Remove FIRST_ARG logic (following systemd-rpm-macros rev 28).
- Avoid em dashes in summary.
- Add %%systemd_ordering as there are service files to process.
* Tue Jan  8 2019 sndirsch@suse.com
- readded support for serial input devices (boo#1120405)
* Tue May 30 2017 sndirsch@suse.com
- includes everything needed for missing sle issue entries:
  fate #315643-315645, 319159-319161, 319618 (bsc#1041642)
* Wed May 10 2017 sndirsch@suse.com
- removed support for serial input devices (fate#323262)
* Thu Apr  6 2017 sndirsch@suse.com
- removed requires to linuxconsoletools (bsc#1032643)
* Sat Mar 18 2017 tchvatal@suse.com
- Version update to 0.34.2:
  * Prevent xf86-input-wacom from binding to pure-keyboard devices
  * refer KeySyms defined by keysymdef.h in man page
  * Make sibling device name matching slightly more lenient
- Remove upstreamed patch:
  * U_conf-rename-to-70-wacom.conf.patch
- Update patch to allow make check to pass, we add option:
  * n_01-Add-option-to-enable-logging.patch
- Run tests
- Drop support for older distros as we care about leap+
* Wed Mar 15 2017 sndirsch@suse.com
- switched input-tools required to linuxconsoletools (bsc#1029489)
* Sat May 21 2016 jengelh@inai.de
- Ensure all unit template instances are gone on uninstall
  [boo#981004]
* Thu May 19 2016 sndirsch@suse.com
- U_conf-rename-to-70-wacom.conf.patch
  * bump up wacom driver to 070, so it get's preferred over
    libinput, which was dropped down to 060 (boo #979554)
* Tue Feb 16 2016 eshmarnev@suse.com
- Update to version 0.32.0:
  * Update release.sh script from Xorg.
  * Don't rely on IsPad() when trying to undo kernel event filtering.
  * Streamline Sourceforge login for release.sh.
* Fri Oct  9 2015 zaitor@opensuse.org
- Update to version 0.31.0:
  + xsetwacom: Fix regression in simple button mapping.
  + Modify wcmMaxCursorDist calculation to support non-inverted
    protocol 4.
* Fri Jul 31 2015 dimstar@opensuse.org
- Update to version 0.30.0:
  + Allow PAD only interfaces without EV_ABS and/or EV_X/Y to
    report events.
  + xsetwacom: Add ability to read args from stdin for fuzzing.
  + afl: xsetwacom:
  - Do not allow negative button numbers.
  - Check that argc is in range before dereferencing argv.
  + ubsan:
  - Fix alignment issues.
  - Prevent out-of-bounds array write.
  - Use 'unsigned int' for button mask in 'wcmSendButtons'.
  + asan: xsetwacom: Cleanup xsetwacom memory leaks.
  + xsetwacom: Fix 'get_mapped_area' ("maptooutput next") on
    64-bit.
  + Coverity:
  - fix potential NULL-pointer dereferences.
  - fix coverity complaints about unchecked return values.
  - fix potential negative array subscript.
  - silence "ioctl return value not checked" warnings.
  - remove dead code.
  + tools: make baudrate unsigned int to shut up compiler.
- BuildRequire pkgconfig(udev) instead of udev: be more robust to
  packaging changes.
- Ignore absence of udevadm, it won't be present in the build env.
- Rebase n_01-Add-option-to-enable-logging.patch.
* Fri Jan 23 2015 sndirsch@suse.com
- Update to release xf86-input-wacom-0.28.0
- dropped upstream patches already in 0.28.0
  * U_01-Remove-unused-code.patch
  * U_02-Zero-is-not-a-valid-device-ID-don-t-derive-a-type-from-it.patch
  * U_03-Fix-initial-device-type-detection.patch
  * U_04-Store-the-last-used-channel-rather-than-blindly-taking-channel-0.patch
  * U_05-Remove-duplicate-tool-type-detection.patch
  * U_06-Attempt-to-derive-the-tool-type-from-a-known-button-key-event.patch
- refreshed logging patches:
  * n_01-Add-option-to-enable-logging.patch
  * n_02-Log-PROXIMITY-LOW-LEVEL-events.patch
  * n_03-Log-PRESSURE-low-level-events.patch
  * n_04-Log-BUTTON-HIGH-LEVEL-events.patch
    (factorX/factorY replaced by 1.0 due to upstream git commit 96eae07)
* Mon Sep  8 2014 eich@suse.com
- readd isdv4-serial-inputattach and isdv4-serial-debugger
  (bnc#895547)
* Thu Apr 10 2014 eich@suse.com
- remove 65-xorg-wacom.rules wacom-inputattach@.service:
  package now ships udev rules and systemd files
* Wed Apr  9 2014 eich@suse.com
- Udate to xf86-input-wacom-0.24.0.tar.bz2
- Remove old set of patches (partly upstreamed)
  * u_01-Fix-message-if-the-detected-pressure-falls-below-the-initially-detected-pressure.patch
  * u_02-Log-when-the-pen-device-appears-to-be-too-worn-out.patch
  * u_03-Add-more-detailed-messaging-in-code-that-handles-abnormal-situations.patch
  * u_04-Avoid-division-by-zero-in-xf86ScaleAxis.patch
  * u_05-Improve-usbInitToolType-tool-type-detection.patch
  * u_06-Add-an-option-to-disable-pressure-recalibration.patch
  * u_07-Add-option-to-enable-logging.patch
  * u_08-Log-PROXIMITY-events.patch
  * u_09-Log-PRESSURE-events.patch
  * u_10-Log-BUTTON-events.patch
- Add upstream patches:
  * U_01-Remove-unused-code.patch
  * U_02-Zero-is-not-a-valid-device-ID-don-t-derive-a-type-from-it.patch
  * U_03-Fix-initial-device-type-detection.patch
  * U_04-Store-the-last-used-channel-rather-than-blindly-taking-channel-0.patch
  * U_05-Remove-duplicate-tool-type-detection.patch
  * U_06-Attempt-to-derive-the-tool-type-from-a-known-button-key-event.patch
- Add logging patches:
  * n_01-Add-option-to-enable-logging.patch
  * n_02-Log-PROXIMITY-LOW-LEVEL-events.patch
  * n_03-Log-PRESSURE-low-level-events.patch
  * n_04-Log-BUTTON-HIGH-LEVEL-events.patch
* Tue Mar 25 2014 coolo@suse.com
- fix udev checking to also work if build service throws udev-mini
  at the build
* Tue Feb 11 2014 eich@suse.com
- u_07-Add-option-to-enable-logging.patch:
  updated patch.
* Tue Feb 11 2014 eich@suse.com
- Add patches to improve logging:
  * u_01-Fix-message-if-the-detected-pressure-falls-below-the-initially-detected-pressure.patch
  * u_02-Log-when-the-pen-device-appears-to-be-too-worn-out.patch
  * u_03-Add-more-detailed-messaging-in-code-that-handles-abnormal-situations.patch
  * u_05-Improve-usbInitToolType-tool-type-detection.patch
  * u_07-Add-option-to-enable-logging.patch
  * u_08-Log-PROXIMITY-events.patch
  * u_09-Log-PRESSURE-events.patch
  * u_10-Log-BUTTON-events.patch
- Fix division-by-zero error message:
  u_04-Avoid-division-by-zero-in-xf86ScaleAxis.patch
- Allow user to disable pressure recalibration
  u_06-Add-an-option-to-disable-pressure-recalibration.patch
* Wed Jan  8 2014 fcrozat@suse.com
- Resync udev rules with Fedora one, add wacom-inputattach@.service
  to attach tablet when plugged (additional dependency on
  input-utils package for inputattach tool).
- Add systemd-rpm-macros (or systemd on old openSUSE release) to
  BuildRequires for systemd service path macro.
- Notify udev to reload its rules on package install/upgrade.
* Sat Dec  7 2013 zaitor@opensuse.org
- Update to version 0.23.0:
  + Correct return value of special_map_button.
  + Fix buffer overflows in 'special_map_*'.
  + Add support for Intuos Pro series.
  + strdup the option key/values in our input_option_new.
  + Print list of supported models on wcmPlug.
* Sat Aug 17 2013 zaitor@opensuse.org
- Update to version 0.22.1:
  + Fix build on ABI < 16 - touch_mask isn't defined.
- Changes from version 0.22.0:
  + Unify wcmFingerMultitouch and wcmSendTouchEvent.
  + Transform touch events just like all other events.
  + Add support for 0xEC.
- Changes from version 0.21.99.1:
  + Add xf86OptionListFree for distcheck.
  + Don't emulate a mouse when multitouch is enabled.
  + Add support for Cintiq 22HDT and 13HD, DTK2241 and DTH2242.
  + Don't init abswheel2 valuator (7th val) if we don't have one.
  + Free the device name after reassigning.
  + Free the touch mask on shutdown.
  + Free input attribute's product.
  + Free duplicated option list after conversion to InputOption.
  + Plug memory leaks left by xf86SetStrOption.
  + Purge TILT_REQUEST_FLAG
  + man: clarify how to configure keys on higher shift levels in
    xsetwacom.
  + xsetwacom:
  - Map a bunch of special symbols.
  - If we fail to map a string, try as special key or warn.
  - Add special mappings for Home, End, Delete.
* Thu Jun 20 2013 fcrozat@suse.com
- Update to version 0.21.0:
  + Handle DEVICE_ABORT on input ABI 19.1
  + Add support for touchscreens direct touch devices
  + Add support for Fujitsu Lifebook T902
- Remove U_Consolidate-calls-to-wcmEvent-into-one-statement.patch
  and U_Consolidate-calls-to-wcmEvent-into-one-statement.patch
  (merged).
- Simplify wacom udev rules (based on Fedora)
* Sat Mar 23 2013 sndirsch@suse.com
- update to release 0.20.0
- U_Resume-button-events-for-pucks.patch
  * Resume button events for pucks (bnc#809182)
- U_Consolidate-calls-to-wcmEvent-into-one-statement.patch
  * required for previous patch
* Thu Jan 24 2013 sndirsch@suse.com
- xf86-input-wacom 0.19.0
  A new year, a new release of xf86-input-wacom. The RC for 0.19.0
  went quite smoothly, with only one additional bug popping up on
  the radar.
  * Properly map 2nd abswheel of Cintiq 24HD touch
* Wed Oct 17 2012 fcrozat@suse.com
- Fix build with new udev rules directory location.
* Mon Sep 17 2012 zaitor@opensuse.org
- Update to version 0.17.0:
  + Add support for Cintiq 22HD
  + Log debug messages in signal-safe manner
  + Use signal-safe logging patches where necessary
  + Set WCM_LCD on the Cintiq 24HD
  + release.sh: support other modules (i.e. libwacom and
    input-wacom)
  + Don't init the rotation property on the pad
- Changes since version 0.15.0:
  + Find mouse buttons on pad devices if no generic buttons found.
  + Re-enable relative wheel scrolling from pad devices
  + Fix a bunch of warnings
  + Add Intuos4 WL (PTK-540WL) to fdi file
* Wed May  9 2012 vuntz@opensuse.org
- Update to version 0.15.0:
  + No changes compared to 0.14.99.1.
* Fri Apr 27 2012 cfarrell@suse.com
- license update: GPL-2.0+
  src/xf86Wacom.c and other files are GPL-2.0+ licensed
* Wed Apr 25 2012 vuntz@opensuse.org
- Update to version 0.14.99.1:
  + Add support for the Intuos5 and DTI-520.
  + Don't share names of action atoms across properties to prevent
    accidental aliasing.
  + Fix configuration to only match Waltop event devices classified
    as tablets.
  + Several small bug fixes.
* Thu Apr 19 2012 dimstar@opensuse.org
- Update to version 0.14.0:
  + wcmXCommand: Fix invalid array size for serial values.
  + Build system fixes
  + Other bugs fixed: fdo#43221, fdo#45557.
- Use %%x11_abi_xinput_req instead of statio ABI Requires.
* Wed Apr 18 2012 vuntz@opensuse.org
- Split xf86-input-wacom from xorg-x11-driver-input.
  Initial version: 0.12.0.
